"""Init composability."""


from gpt_index.composability.graph import ComposableGraph

__all__ = ["ComposableGraph"]
